/* 
 * meta node
 *
 * $Id: nMeta.h 725 2008-04-14 00:04:49Z jon13 $
 *
 * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
 */

#ifndef _NMETA_H
#define _NMETA_H

#include "meta.h"

void nMetaInit(void);

#endif /* _NMETA_H */
